'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var sewingKit = require('@quilted/sewing-kit');

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () {
            return e[k];
          }
        });
      }
    });
  }
  n['default'] = e;
  return Object.freeze(n);
}

/**
 * Adds basic Babel hooks that other plugins can attach configuration to.
 */
function babelHooks() {
  return sewingKit.createProjectPlugin({
    name: 'SewingKit.Babel',

    build({
      hooks
    }) {
      hooks(({
        waterfall
      }) => ({
        babelPlugins: waterfall(),
        babelPresets: waterfall(),
        babelExtensions: waterfall(),
        babelTargets: waterfall()
      }));
    },

    develop({
      hooks
    }) {
      hooks(({
        waterfall
      }) => ({
        babelPlugins: waterfall(),
        babelPresets: waterfall(),
        babelExtensions: waterfall(),
        babelTargets: waterfall()
      }));
    },

    test({
      hooks
    }) {
      hooks(({
        waterfall
      }) => ({
        babelPlugins: waterfall(),
        babelPresets: waterfall(),
        babelExtensions: waterfall(),
        babelTargets: waterfall()
      }));
    }

  });
}
/**
 * Adds basic Babel hooks that other plugins can attach configuration to
 * for configuring Babel at the workspace level.
 */

function babelWorkspaceHooks() {
  return sewingKit.createWorkspacePlugin({
    name: 'SewingKit.Babel.Workspace',

    build({
      hooks
    }) {
      hooks(({
        waterfall
      }) => ({
        babelPlugins: waterfall(),
        babelPresets: waterfall(),
        babelExtensions: waterfall(),
        babelTargets: waterfall()
      }));
    },

    develop({
      hooks
    }) {
      hooks(({
        waterfall
      }) => ({
        babelPlugins: waterfall(),
        babelPresets: waterfall(),
        babelExtensions: waterfall(),
        babelTargets: waterfall()
      }));
    },

    test({
      hooks
    }) {
      hooks(({
        waterfall
      }) => ({
        babelPlugins: waterfall(),
        babelPresets: waterfall(),
        babelExtensions: waterfall(),
        babelTargets: waterfall()
      }));
    }

  });
}
function babelRollup() {
  return sewingKit.createProjectPlugin({
    name: 'SewingKit.Babel.Rollup',

    build({
      project,
      configure
    }) {
      configure(({
        extensions,
        babelPresets,
        babelPlugins,
        babelTargets,
        babelExtensions,
        rollupPlugins
      }) => {
        rollupPlugins?.(async plugins => {
          const shouldUseRuntime = project.kind === sewingKit.ProjectKind.Package ? 'runtime' : 'bundled';
          const [{
            babel
          }, targets, baseExtensions, babelPresetsOption, babelPluginsOption] = await Promise.all([Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require('@rollup/plugin-babel')); }), babelTargets.run([]), extensions.run(['.mjs', '.cjs', '.js']), babelPresets.run([]), babelPlugins.run(shouldUseRuntime ? ['@babel/plugin-transform-runtime'] : [])]);
          const finalExtensions = await babelExtensions.run(baseExtensions);
          return [...plugins, babel({
            envName: 'production',
            extensions: finalExtensions,
            exclude: 'node_modules/**',
            babelHelpers: shouldUseRuntime ? 'runtime' : 'bundled',
            configFile: false,
            babelrc: false,
            skipPreflightCheck: true,
            // @ts-expect-error Babel types have not been updated yet
            targets,
            presets: babelPresetsOption,
            plugins: babelPluginsOption
          })];
        });
      });
    },

    develop({
      project,
      configure
    }) {
      configure(({
        extensions,
        babelPresets,
        babelPlugins,
        babelTargets,
        babelExtensions,
        rollupPlugins
      }) => {
        rollupPlugins?.(async plugins => {
          const shouldUseRuntime = project.kind === sewingKit.ProjectKind.Package ? 'runtime' : 'bundled';
          const [{
            babel
          }, targets, baseExtensions, babelPresetsOption, babelPluginsOption] = await Promise.all([Promise.resolve().then(function () { return /*#__PURE__*/_interopNamespace(require('@rollup/plugin-babel')); }), babelTargets.run([]), extensions.run(['.mjs', '.cjs', '.js']), babelPresets.run([]), babelPlugins.run(shouldUseRuntime ? ['@babel/plugin-transform-runtime'] : [])]);
          const finalExtensions = await babelExtensions.run(baseExtensions);
          return [...plugins, babel({
            envName: 'production',
            extensions: finalExtensions,
            exclude: 'node_modules/**',
            babelHelpers: shouldUseRuntime ? 'runtime' : 'bundled',
            configFile: false,
            babelrc: false,
            skipPreflightCheck: true,
            // @ts-expect-error Babel types have not been updated yet
            targets,
            presets: babelPresetsOption,
            plugins: babelPluginsOption
          })];
        });
      });
    }

  });
}

exports.babelHooks = babelHooks;
exports.babelRollup = babelRollup;
exports.babelWorkspaceHooks = babelWorkspaceHooks;
